@@ -24,11 +24,29 @@
 wk_plot <- function(handleable, ...,
                     asp = 1, bbox = NULL, xlab = "", ylab = "",
                     rule = "evenodd", add = FALSE) {
+  UseMethod("wk_plot")
+}
+
+#' @rdname wk_plot
+#' @export
+wk_plot.default <- function(handleable, ...,
+                            asp = 1, bbox = NULL, xlab = "", ylab = "",
+                            rule = "evenodd", add = FALSE) {
   # this is too hard without vctrs (already in Suggests)
   if (!requireNamespace("vctrs", quietly = TRUE)) {
     stop("Package 'vctrs' is required for wk_plot()", call. = FALSE) # nocov
   }
 
+  if (isTRUE(wk_is_geodesic(handleable))) {
+    stop(
+      paste0(
+        "wk_plot.default() can't plot geodesic objects.\n",
+        "Use `wk_set_geodesic(x, FALSE)` to ignore geodesic edge specification"
+      ),
+      call. = FALSE
+    )
+  }
+
   # should be refactored
   x <- handleable
 
@@ -60,7 +78,7 @@ wk_plot <- function(handleable, ...,
   meta <- wk_meta(x)
 
   # points can be handled by as_xy()
-  if (all(meta$geometry_type == 1L)) {
+  if (all(meta$geometry_type == 1L, na.rm = TRUE)) {
     coords <- unclass(as_xy(x))
     graphics::points(coords, ...)
     return(invisible(x))
@@ -75,7 +93,7 @@ wk_plot <- function(handleable, ...,
   is_rule <- length(dots)
 
   # point + multipoint is probably faster with a single coord vector
-  if (all(meta$geometry_type %in% c(1, 4))) {
+  if (all(meta$geometry_type %in% c(1, 4), na.rm = TRUE)) {
     coords <- wk_coords(x)
     if (dots_constant) {
       graphics::points(coords[c("x", "y")], ...)
@@ -101,7 +119,7 @@ wk_plot <- function(handleable, ...,
     } else if (meta$geometry_type[i] %in% c(3, 6)) {
       wk_plot_poly_or_multi_poly(xi, dotsi)
     } else {
-      do.call(wk_plot, c(list(wk_flatten(xi, max_depth = .Machine$integer.max)), dotsi))
+      do.call(wk_plot, c(list(wk_flatten(xi, max_depth = .Machine$integer.max), add = TRUE), dotsi))
     }
   }
 
@@ -109,12 +127,17 @@ wk_plot <- function(handleable, ...,
 }
 
 wk_plot_point_or_multipoint <- function(x, dots) {
+  dots_without_border <- dots[setdiff(names(dots), "border")]
   coords <- wk_coords(x)
-  do.call(graphics::points, c(coords[c("x", "y")], dots))
+  do.call(graphics::points, c(coords[c("x", "y")], dots_without_border))
 }
 
 wk_plot_line_or_multiline <- function(x, dots) {
   coords <- wk_coords(x)
+  if (nrow(coords) == 0) {
+    return()
+  }
+
   geom_id <- coords$part_id
   geom_id_lag <- c(-1L, geom_id[-length(geom_id)])
   new_geom <- geom_id != geom_id_lag
@@ -133,6 +156,9 @@ wk_plot_line_or_multiline <- function(x, dots) {
 
 wk_plot_poly_or_multi_poly <- function(x, dots) {
   coords <- wk_coords(x)
+  if (nrow(coords) == 0) {
+    return()
+  }
 
   # for polygons we can use the coord vectors directly
   # because the graphics device expects open loops
